#ifndef MAINWINDOW_H
#define MAINWINDOW_H

#include <QMainWindow>
#include <QModelIndex>
#include <QPushButton>
#include <QAction>
#include <phonon>
#include <QListWidgetItem>


class SymfonieMediaPlayer;
class SymfonieInfoWindow;
class SymfoniePlayList;
class QLabel;
class QTimer;
class QApplication;
class SymfonieTimerWindow;
class SymfonieEqualizerWindow;
class SymfonieFileTypesDialog;


namespace Ui {
    class MainWindow;
}

class MainWindow : public QMainWindow {
    Q_OBJECT
public:
    MainWindow(const QApplication *app, SymfonieMediaPlayer* player, QWidget *parent = 0);
    ~MainWindow();
    void setPlayer(SymfonieMediaPlayer *player);

    QString getCurrentDiretory();
    void setCurrentDirectory(QString);

    SymfonieMediaPlayer * getPlayer();
    void setPO();
    void setHO();


protected:
    void changeEvent(QEvent *e);

private:
    Ui::MainWindow *ui;
    SymfonieMediaPlayer *player;
    QString curentDirectory;
    SymfoniePlayList* currentPlayList;
    void insertItem(SymfoniePlayList* );
    QTimer *timer;
    SymfonieTimerWindow *timerWindow;
    SymfonieEqualizerWindow *equalizerWindow;
    const QApplication *app;
    SymfonieFileTypesDialog *fileTypesDialog;


    QAction *playAction;
    QAction *stopAction;
    QAction *prevAction;
    QAction *nextAction;
    QAction *switchOrientationAction;
    QAction *showInfoWindowAction;
    QAction *showToolBar2Action;
    QAction *goUpAction;
    QAction *goHomeAction;
    QAction *goToCurDir;
    QAction *toggleFullScreenAction;

    QActionGroup *orientationGroup;
    QAction *orientationLandscape;
    QAction *orientationPortrait;
    QAction *orientationAuto;

    QWidget *ww;
    bool isInPortait;

    SymfonieInfoWindow* infoWindow;
    Phonon::SeekSlider *seekSlider;
    Phonon::VolumeSlider *volumeSlider;

    void setActionToggleState();

    SymfoniePlayList* createHomePlayList();
    void saveState();
    bool saveLastDir();
    bool isResumePlayback;
   // void notifyInfo(QString);

    void setMenuActionTimerText(int time);


private Q_SLOTS:
    void itemActivatedSlot(QModelIndex);
    void mediaStateChangedSlot(Phonon::State newState, Phonon::State oldState);
    void stopSlot();
    void playSlot();
    void playNextSlot();
    void playPrevSlot();
    void playerDirectoryChangedSlot(QString);
    void playerScanDirCompletedSlot(SymfoniePlayList*, QString);
    void switchOrientationSlot();
    void showInfoWindowSlot();
    void showToolBar2Slot();
    void goHomeSlot();
    void goUpSlot();
    void playerTickSlot(qint64 time);
    void goToCurDirSlot();
    void showAboutWindowSlot();
    void showTimerWindowSlot();
    void updateTimerSlot(int time);
    void showEqualizerWindowSlot();
    void toggleFullScreen(bool b);
    void toggleFullScreenOn();
    void toggleFullScreenOff();
    void orientationChanged(QAction *action);
    void playerTimerStoppedSlot();
    void clearTimerSlot();
    void playerTimerRemainTimeChangedSlot(int);
    void equalizerWindowEnabledStateChangedSlot(bool value);
    void showFileTypesWindowSlot();
    void fileTypesChangedSlot(QStringList list);

};

#endif // MAINWINDOW_H

